@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP::Server;
 use vars '$VERSION';
-$VERSION = '3.09';
+$VERSION = '3.10';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -79,8 +79,7 @@ sub compileHandler(@)
                    , $self->faultNoAnswerProduced($name));
         }
 
-        my $rc = (delete $answer->{_RETURN_CODE})
-              || ($answer->{Fault} ? RC_BAD_REQUEST : RC_OK);
+        my $rc     = (delete $answer->{_RETURN_CODE}) || RC_OK;
         my $rc_txt = delete $answer->{_RETURN_TEXT} || 'Answer included';
 
         my $xmlout = try { $encode->($answer) };
